<?php
/*
Plugin Name: WP Title Case
Plugin URI: http://thisismyurl.com/plugins/wp-title-case/
Description: Automatically applied title case rules to WordPress titles. This plugin automatically updates Page and Post titles to follow title casing rules.
Author: Christopher Ross
Author URI: http://thisismyurl.com/plugins/
Tags: texts, titlecase, title case, auto, automatic, uppercase, lowercase, ucfirst
Version: 14.12
*/

/**
 * WP Title Case core file
 *
 * This file contains all the logic required for the plugin
 *
 * @link		http://wordpress.org/extend/plugins/wp-title-case/
 *
 * @package 	WP Title Case
 * @copyright	Copyright (c) 2008, Chrsitopher Ross
 * @license		http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License, v2 (or newer)
 *
 * @since 		WP Title Case 1.0
 */



/**
 * Applies title case rules to strings
 *
 * @param string $text_to_alter the string to apply text rules to
 * @return string  $text_to_alter with rules applied
 *
 * @author Christopher Ross <@thisismyurl>
 * @version 1.2.1
 * @package WP Title Case
 *
 */
function thisismyurl_title_case( $text_to_alter = NULL ) {

	$options = get_option( 'thisismyurl_title_case' );
	if ( empty( $options['text_too_short_to_process'] ) )
		$options['text_too_short_to_process'] = 2;

	$words_to_ignore = explode( ',', trim( strtolower( $options['ignore_words'] ) ) );
	foreach ( $words_to_ignore as $words ) {
		$cleaned_words_to_ignore[] = trim( $words ) ;
	}

	if ( $text_to_alter ) {

		$altered_text_array = preg_split( '/((^\p{P}+)|(\p{P}*\s+\p{P}*)|(\p{P}+$))/' , trim( $text_to_alter ), -1, PREG_SPLIT_NO_EMPTY );

		if ( $altered_text_array  ) {

			for ( $i = 0; $i < count( $altered_text_array ); $i++ ) {

				if ( !in_array( strtolower( $altered_text_array[$i] ), $cleaned_words_to_ignore ) ) {

					$altered_text_array[$i] = strtolower( $altered_text_array[$i] );
					if ( 0 == $i || strlen( $altered_text_array[$i] ) > $options['text_too_short_to_process'] )
						$result_text_array[$i] = trim( ucfirst( $altered_text_array[$i] ) );
					else
						$result_text_array[$i] = trim( $altered_text_array[$i] );
				} else {
					$result_text_array[$i] = trim( $altered_text_array[$i] );
				}
			}
			$result_text = implode( ' ', $result_text_array );

		}

		return $result_text;

	}

}

add_filter( 'the_title', 'thisismyurl_title_case' );
add_filter( 'wp_title', 'thisismyurl_title_case' );
add_filter( 'the_title_rss', 'thisismyurl_title_case' );

/**
 * Adds an About link to the plugins menu
 */
function thisismyurl_title_case_plugin_page_menu( $links, $file ){

	static $this_plugin;

	if( !$this_plugin )
		$this_plugin = plugin_basename( __FILE__);

	if( $file == $this_plugin ){
		$links[] = '<a href="options-general.php?page=thisismyurl_title_case">' . __( 'Settings', 'thisismyurl_title_case' ) . '</a>';
		$links[] = '<a href="http://thisismyurl.com/plugins/wp-title-case/">thisismyurl.com</a>';
	}
	return $links;
}
add_filter( 'plugin_action_links', 'thisismyurl_title_case_plugin_page_menu', 10, 2);

/**
 *
 * Initialize the plugin
 *
 */
function thisismyurl_title_case_init(){
	register_setting( 'thisismyurl_title_case_options', 'thisismyurl_title_case', 'thisismyurl_title_case_validate' );
}
add_action('admin_init', 'thisismyurl_title_case_init' );


/**
 *
 * Add the option page
 *
 */
function thisismyurl_title_case_add_page() {
	add_options_page( __( 'WP Title Case', 'thisismyurl_title_case' ), __( 'WP Title Case', 'thisismyurl_title_case' ), 'manage_options', 'thisismyurl_title_case', 'thisismyurl_title_case_settings_page');
}
add_action('admin_menu', 'thisismyurl_title_case_add_page');

/**
 *
 * Options page for WP Title Case
 *
 */
function thisismyurl_title_case_settings_page() {
	?>
	<div class="wrap">
		<div class="thisismyurl-icon32 icon32"><br /></div>
		<h2><?php _e( 'WP Title Case by Christopher Ross', 'thisismyurl_title_case' ) ?></h2>
		<p>Automatically applied title case rules to WordPress titles. This plugin automatically updates Page and Post titles to follow title casing rules.</p>

		<h3>General Settings</h3>
		<form method="post" action="options.php">
			<?php settings_fields( 'thisismyurl_title_case_options' ); ?>
			<?php $options = get_option( 'thisismyurl_title_case' ); ?>
			<table class="form-table">
				<tr valign="top"><th scope="row"><?php _e( 'Ignore short words', 'thisismyurl_title_case' ) ?></th>
					<td>

					<select name="thisismyurl_title_case[text_too_short_to_process]" id="thisismyurl_title_case[text_too_short_to_process]">
						<?php
						if ( empty( $options['text_too_short_to_process'] ) )
							$options['text_too_short_to_process'] = 2;

						for ( $i = 1; $i < 8; $i++ ) { ?>
						<option value="<?php echo $i;?>" <?php if ( $options['text_too_short_to_process'] == $i ) echo 'selected'; ?>><?php echo $i;?></option>
						<?php } ?>
					</select>

					<br/ ><em><?php _e( 'Select the minimum legth of words to process', 'thisismyurl_title_case' ) ?></em></td>
				</tr>

				<tr valign="top"><th scope="row"><?php _e( 'Words to Ignore', 'thisismyurl_title_case' ) ?></th>
					<td>

					<textarea value="" id="thisismyurl_title_case[ignore_words]" name="thisismyurl_title_case[ignore_words]"><?php echo $options['ignore_words'];?></textarea>

					<br/ ><em><?php _e( 'A list of comma seperated words to ignore.', 'thisismyurl_title_case' ) ?></em></td>
				</tr>

			</table>
			<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			</p>
		</form>

	</div>
	<?php

}


/**
 *
 * Validate the input
 *
 */
function thisismyurl_title_case_validate( $input ) {
	// Our first value is either 0 or 1
	if ( empty( $input['text_too_short_to_process'] ) )
		$input['text_too_short_to_process'] = 2;

	return $input;
}

/**
 *
 * Adds CSS to the WordPress admin for this plugin
 *
 */
function thisismyurl_title_case_wordpress_scripts() {
	

	if ( 'edit.php' != $hook )
        return;

	wp_register_style( 'thisismyurl-admin-css', plugin_dir_url( __FILE__ ) . 'css/thisismyurl-admin.css', false, '1.0.0' );
    wp_enqueue_style( 'thisismyurl-admin-css' );

}
add_action( 'admin_enqueue_scripts', 'thisismyurl_title_case_wordpress_scripts' );
